@@ -94,7 +94,7 @@ test_that("Combinations - icombinations", {
     expect_equal(length(icomb$getnext()), 0)
     expect_equal(icomb$getnext(), NULL)
     icomb <- icombinations(10, 11)
-    expect_equal(icomb$collect(), NULL)
+    expect_equal(dim(icomb$collect()), c(0, 11))
     expect_equal(icomb$getnext(), NULL)
     expect_error(icombinations(10, -1), "expect integer")
     expect_error(icombinations(10, 1.5), "expect integer")
@@ -105,15 +105,15 @@ test_that("Combinations - index", {
     expect_equal(combinations(5, 3, index = as.numeric(1:10)), combinations(5, 3))
     expect_equal(combinations(5, 3, index = as.character(1:10)), combinations(5, 3))
     expect_equal(combinations(5, 3, index = gmp::as.bigz(1:10)), combinations(5, 3))
-    expect_equal(combinations(5, 3, index = 2)[1, ], c(1, 2, 4))
-    expect_equal(combinations(5, 3, index = 10)[1, ], c(3, 4, 5))
+    expect_equal(combinations(5, 3, index = 2), c(1, 2, 4))
+    expect_equal(combinations(5, 3, index = 10), c(3, 4, 5))
     expect_error(combinations(5, 3, index = -1), "expect integer")
     expect_error(combinations(5, 3, index = 1.5), "expect integer")
     expect_error(combinations(5, 3, index = "-1"), "expect integer")
     expect_error(combinations(5, 3, index = "1.5"), "expect integer")
 
-    expect_equal(combinations(50, 30, index = 2)[1, ], c(1:29, 31))
-    expect_equal(combinations(50, 30, index = ncombinations(50, 30, bigz = TRUE))[1, ], 21:50)
+    expect_equal(combinations(50, 30, index = 2), c(1:29, 31))
+    expect_equal(combinations(50, 30, index = ncombinations(50, 30, bigz = TRUE)), 21:50)
     expect_error(combinations(50, 30, index = -1), "expect integer")
     expect_error(combinations(50, 30, index = 1.5), "expect integer")
     expect_error(combinations(50, 30, index = "-1"), "expect integer")
